<tr>
    <td class="text-center">{{ service_name }}</td>
    <td class="text-center">{{ username }}</td>
        {% if username == "" %}
            <td class="text-center">{{ service_url }}</td>
            <td class="text-center">
            <a href="{% url 'mumble:activate' %}" title="Activate" class="btn btn-warning">
                <span class="glyphicon glyphicon-ok"></span>
            </a>
        </td>
        {% else %}
            <td class="text-center"><a href="mumble://{{ connect_url }}">{{ service_url }}</a></td>
            <td class="text-center">
            <a href="{% url 'mumble:set_password' %}" title="Set Password" class="btn btn-warning">
                <span class="glyphicon glyphicon-pencil"></span>
            </a>
            <a href="{% url 'mumble:reset_password' %}" title="Reset Password" class="btn btn-primary">
                <span class="glyphicon glyphicon-refresh"></span>
            </a>
            <a href="{% url 'mumble:deactivate' %}" title="Deactivate" class="btn btn-danger">
                <span class="glyphicon glyphicon-remove"></span>
            </a>
            <a href="mumble://{{ connect_url }}" class="btn btn-success" title="Connect">
                <span class="glyphicon glyphicon-arrow-right"></span>
            </a>
        </td>
        {% endif %}
</tr>
